# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/cluster.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15gateway/cluster.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdb\x04\n\x07\x43luster\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12*\n\x0bgke_cluster\x18\x02 \x01(\x0b\x32\x13.gateway.GkeClusterH\x00\x12*\n\x0b\x65ks_cluster\x18\x07 \x01(\x0b\x32\x13.gateway.EksClusterH\x00\x12,\n\x0c\x66\x61ke_cluster\x18\x03 \x01(\x0b\x32\x14.gateway.FakeClusterH\x00\x12\x34\n\x10minikube_cluster\x18\x04 \x01(\x0b\x32\x18.gateway.MinikubeClusterH\x00\x12;\n\x0b\x61nnotations\x18\n \x03(\x0b\x32!.gateway.Cluster.AnnotationsEntryB\x03\xe0\x41\x01\x12-\n\x05state\x18\x05 \x01(\x0e\x32\x16.gateway.Cluster.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x0e\n\x0c\x63luster_type\"\xa4\x01\n\nGkeCluster\x12\x1a\n\nproject_id\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x18\n\x08location\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1c\n\x0c\x63luster_name\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rrepository_id\x18\x05 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12#\n\x13storage_bucket_name\x18\x06 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"\xfa\x02\n\nEksCluster\x12\x1e\n\x0e\x61ws_account_id\x18\t \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12&\n\x16\x66ireworks_manager_role\x18\x01 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x16\n\x06region\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1c\n\x0c\x63luster_role\x18\x04 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\'\n\x17\x63luster_autoscaler_role\x18\n \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12 \n\x10system_node_role\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1a\n\nsubnet_ids\x18\x05 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1c\n\x0c\x63luster_name\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0frepository_name\x18\x06 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12#\n\x13storage_bucket_name\x18\x08 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12#\n\x13node_security_group\x18\x0b \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"!\n\x0fMinikubeCluster\x12\x0e\n\x06server\x18\x01 \x01(\t\"I\n\x0b\x46\x61keCluster\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x03 \x01(\t\"l\n\x14\x43reateClusterRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12&\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x10.gateway.ClusterB\x03\xe0\x41\x02\x12\x17\n\ncluster_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"&\n\x11GetClusterRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\",\n\x17ReconcileClusterRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x87\x01\n\x13ListClustersRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"g\n\x14ListClustersResponse\x12\"\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x10.gateway.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\">\n\x14UpdateClusterRequest\x12&\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.gateway.ClusterB\x03\xe0\x41\x02\")\n\x14\x44\x65leteClusterRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"4\n\x1fGetClusterConnectionInfoRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\":\n\x15\x43lusterConnectionInfo\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61_data\x18\x02 \x01(\tB\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_CLUSTER_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.Cluster.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=629,
  serialized_end=710,
)
_sym_db.RegisterEnumDescriptor(_CLUSTER_STATE)


_CLUSTER_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='gateway.Cluster.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.Cluster.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.Cluster.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=577,
  serialized_end=627,
)

_CLUSTER = _descriptor.Descriptor(
  name='Cluster',
  full_name='gateway.Cluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.Cluster.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.Cluster.display_name', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.Cluster.create_time', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gke_cluster', full_name='gateway.Cluster.gke_cluster', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eks_cluster', full_name='gateway.Cluster.eks_cluster', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fake_cluster', full_name='gateway.Cluster.fake_cluster', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minikube_cluster', full_name='gateway.Cluster.minikube_cluster', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='gateway.Cluster.annotations', index=7,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.Cluster.state', index=8,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.Cluster.status', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTER_ANNOTATIONSENTRY, ],
  enum_types=[
    _CLUSTER_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_type', full_name='gateway.Cluster.cluster_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=123,
  serialized_end=726,
)


_GKECLUSTER = _descriptor.Descriptor(
  name='GkeCluster',
  full_name='gateway.GkeCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='gateway.GkeCluster.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='gateway.GkeCluster.location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='gateway.GkeCluster.cluster_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repository_id', full_name='gateway.GkeCluster.repository_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_bucket_name', full_name='gateway.GkeCluster.storage_bucket_name', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=893,
)


_EKSCLUSTER = _descriptor.Descriptor(
  name='EksCluster',
  full_name='gateway.EksCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws_account_id', full_name='gateway.EksCluster.aws_account_id', index=0,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fireworks_manager_role', full_name='gateway.EksCluster.fireworks_manager_role', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='gateway.EksCluster.region', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_role', full_name='gateway.EksCluster.cluster_role', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_autoscaler_role', full_name='gateway.EksCluster.cluster_autoscaler_role', index=4,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system_node_role', full_name='gateway.EksCluster.system_node_role', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='gateway.EksCluster.subnet_ids', index=6,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='gateway.EksCluster.cluster_name', index=7,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='gateway.EksCluster.repository_name', index=8,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_bucket_name', full_name='gateway.EksCluster.storage_bucket_name', index=9,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_security_group', full_name='gateway.EksCluster.node_security_group', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=1274,
)


_MINIKUBECLUSTER = _descriptor.Descriptor(
  name='MinikubeCluster',
  full_name='gateway.MinikubeCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='gateway.MinikubeCluster.server', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1276,
  serialized_end=1309,
)


_FAKECLUSTER = _descriptor.Descriptor(
  name='FakeCluster',
  full_name='gateway.FakeCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='gateway.FakeCluster.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='gateway.FakeCluster.location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='gateway.FakeCluster.cluster_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1311,
  serialized_end=1384,
)


_CREATECLUSTERREQUEST = _descriptor.Descriptor(
  name='CreateClusterRequest',
  full_name='gateway.CreateClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateClusterRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='gateway.CreateClusterRequest.cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='gateway.CreateClusterRequest.cluster_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1494,
)


_GETCLUSTERREQUEST = _descriptor.Descriptor(
  name='GetClusterRequest',
  full_name='gateway.GetClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetClusterRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1496,
  serialized_end=1534,
)


_RECONCILECLUSTERREQUEST = _descriptor.Descriptor(
  name='ReconcileClusterRequest',
  full_name='gateway.ReconcileClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.ReconcileClusterRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1536,
  serialized_end=1580,
)


_LISTCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListClustersRequest',
  full_name='gateway.ListClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListClustersRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListClustersRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListClustersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListClustersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListClustersRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1583,
  serialized_end=1718,
)


_LISTCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListClustersResponse',
  full_name='gateway.ListClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusters', full_name='gateway.ListClustersResponse.clusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListClustersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListClustersResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1720,
  serialized_end=1823,
)


_UPDATECLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateClusterRequest',
  full_name='gateway.UpdateClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='gateway.UpdateClusterRequest.cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1825,
  serialized_end=1887,
)


_DELETECLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteClusterRequest',
  full_name='gateway.DeleteClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteClusterRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1889,
  serialized_end=1930,
)


_GETCLUSTERCONNECTIONINFOREQUEST = _descriptor.Descriptor(
  name='GetClusterConnectionInfoRequest',
  full_name='gateway.GetClusterConnectionInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetClusterConnectionInfoRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1932,
  serialized_end=1984,
)


_CLUSTERCONNECTIONINFO = _descriptor.Descriptor(
  name='ClusterConnectionInfo',
  full_name='gateway.ClusterConnectionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='gateway.ClusterConnectionInfo.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ca_data', full_name='gateway.ClusterConnectionInfo.ca_data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1986,
  serialized_end=2044,
)

_CLUSTER_ANNOTATIONSENTRY.containing_type = _CLUSTER
_CLUSTER.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CLUSTER.fields_by_name['gke_cluster'].message_type = _GKECLUSTER
_CLUSTER.fields_by_name['eks_cluster'].message_type = _EKSCLUSTER
_CLUSTER.fields_by_name['fake_cluster'].message_type = _FAKECLUSTER
_CLUSTER.fields_by_name['minikube_cluster'].message_type = _MINIKUBECLUSTER
_CLUSTER.fields_by_name['annotations'].message_type = _CLUSTER_ANNOTATIONSENTRY
_CLUSTER.fields_by_name['state'].enum_type = _CLUSTER_STATE
_CLUSTER.fields_by_name['status'].message_type = gateway_dot_status__pb2._STATUS
_CLUSTER_STATE.containing_type = _CLUSTER
_CLUSTER.oneofs_by_name['cluster_type'].fields.append(
  _CLUSTER.fields_by_name['gke_cluster'])
_CLUSTER.fields_by_name['gke_cluster'].containing_oneof = _CLUSTER.oneofs_by_name['cluster_type']
_CLUSTER.oneofs_by_name['cluster_type'].fields.append(
  _CLUSTER.fields_by_name['eks_cluster'])
_CLUSTER.fields_by_name['eks_cluster'].containing_oneof = _CLUSTER.oneofs_by_name['cluster_type']
_CLUSTER.oneofs_by_name['cluster_type'].fields.append(
  _CLUSTER.fields_by_name['fake_cluster'])
_CLUSTER.fields_by_name['fake_cluster'].containing_oneof = _CLUSTER.oneofs_by_name['cluster_type']
_CLUSTER.oneofs_by_name['cluster_type'].fields.append(
  _CLUSTER.fields_by_name['minikube_cluster'])
_CLUSTER.fields_by_name['minikube_cluster'].containing_oneof = _CLUSTER.oneofs_by_name['cluster_type']
_CREATECLUSTERREQUEST.fields_by_name['cluster'].message_type = _CLUSTER
_LISTCLUSTERSRESPONSE.fields_by_name['clusters'].message_type = _CLUSTER
_UPDATECLUSTERREQUEST.fields_by_name['cluster'].message_type = _CLUSTER
DESCRIPTOR.message_types_by_name['Cluster'] = _CLUSTER
DESCRIPTOR.message_types_by_name['GkeCluster'] = _GKECLUSTER
DESCRIPTOR.message_types_by_name['EksCluster'] = _EKSCLUSTER
DESCRIPTOR.message_types_by_name['MinikubeCluster'] = _MINIKUBECLUSTER
DESCRIPTOR.message_types_by_name['FakeCluster'] = _FAKECLUSTER
DESCRIPTOR.message_types_by_name['CreateClusterRequest'] = _CREATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['GetClusterRequest'] = _GETCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['ReconcileClusterRequest'] = _RECONCILECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['ListClustersRequest'] = _LISTCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListClustersResponse'] = _LISTCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateClusterRequest'] = _UPDATECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteClusterRequest'] = _DELETECLUSTERREQUEST
DESCRIPTOR.message_types_by_name['GetClusterConnectionInfoRequest'] = _GETCLUSTERCONNECTIONINFOREQUEST
DESCRIPTOR.message_types_by_name['ClusterConnectionInfo'] = _CLUSTERCONNECTIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTER_ANNOTATIONSENTRY,
    '__module__' : 'gateway.cluster_pb2'
    # @@protoc_insertion_point(class_scope:gateway.Cluster.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _CLUSTER,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.Cluster)
  })
_sym_db.RegisterMessage(Cluster)
_sym_db.RegisterMessage(Cluster.AnnotationsEntry)

GkeCluster = _reflection.GeneratedProtocolMessageType('GkeCluster', (_message.Message,), {
  'DESCRIPTOR' : _GKECLUSTER,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GkeCluster)
  })
_sym_db.RegisterMessage(GkeCluster)

EksCluster = _reflection.GeneratedProtocolMessageType('EksCluster', (_message.Message,), {
  'DESCRIPTOR' : _EKSCLUSTER,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.EksCluster)
  })
_sym_db.RegisterMessage(EksCluster)

MinikubeCluster = _reflection.GeneratedProtocolMessageType('MinikubeCluster', (_message.Message,), {
  'DESCRIPTOR' : _MINIKUBECLUSTER,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.MinikubeCluster)
  })
_sym_db.RegisterMessage(MinikubeCluster)

FakeCluster = _reflection.GeneratedProtocolMessageType('FakeCluster', (_message.Message,), {
  'DESCRIPTOR' : _FAKECLUSTER,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.FakeCluster)
  })
_sym_db.RegisterMessage(FakeCluster)

CreateClusterRequest = _reflection.GeneratedProtocolMessageType('CreateClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLUSTERREQUEST,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateClusterRequest)
  })
_sym_db.RegisterMessage(CreateClusterRequest)

GetClusterRequest = _reflection.GeneratedProtocolMessageType('GetClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERREQUEST,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetClusterRequest)
  })
_sym_db.RegisterMessage(GetClusterRequest)

ReconcileClusterRequest = _reflection.GeneratedProtocolMessageType('ReconcileClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _RECONCILECLUSTERREQUEST,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ReconcileClusterRequest)
  })
_sym_db.RegisterMessage(ReconcileClusterRequest)

ListClustersRequest = _reflection.GeneratedProtocolMessageType('ListClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSREQUEST,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListClustersRequest)
  })
_sym_db.RegisterMessage(ListClustersRequest)

ListClustersResponse = _reflection.GeneratedProtocolMessageType('ListClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLUSTERSRESPONSE,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListClustersResponse)
  })
_sym_db.RegisterMessage(ListClustersResponse)

UpdateClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLUSTERREQUEST,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateClusterRequest)
  })
_sym_db.RegisterMessage(UpdateClusterRequest)

DeleteClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLUSTERREQUEST,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteClusterRequest)
  })
_sym_db.RegisterMessage(DeleteClusterRequest)

GetClusterConnectionInfoRequest = _reflection.GeneratedProtocolMessageType('GetClusterConnectionInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLUSTERCONNECTIONINFOREQUEST,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetClusterConnectionInfoRequest)
  })
_sym_db.RegisterMessage(GetClusterConnectionInfoRequest)

ClusterConnectionInfo = _reflection.GeneratedProtocolMessageType('ClusterConnectionInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONNECTIONINFO,
  '__module__' : 'gateway.cluster_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ClusterConnectionInfo)
  })
_sym_db.RegisterMessage(ClusterConnectionInfo)


DESCRIPTOR._options = None
_CLUSTER_ANNOTATIONSENTRY._options = None
_CLUSTER.fields_by_name['name']._options = None
_CLUSTER.fields_by_name['display_name']._options = None
_CLUSTER.fields_by_name['create_time']._options = None
_CLUSTER.fields_by_name['annotations']._options = None
_CLUSTER.fields_by_name['state']._options = None
_CLUSTER.fields_by_name['status']._options = None
_GKECLUSTER.fields_by_name['project_id']._options = None
_GKECLUSTER.fields_by_name['location']._options = None
_GKECLUSTER.fields_by_name['cluster_name']._options = None
_GKECLUSTER.fields_by_name['repository_id']._options = None
_GKECLUSTER.fields_by_name['storage_bucket_name']._options = None
_EKSCLUSTER.fields_by_name['aws_account_id']._options = None
_EKSCLUSTER.fields_by_name['fireworks_manager_role']._options = None
_EKSCLUSTER.fields_by_name['region']._options = None
_EKSCLUSTER.fields_by_name['cluster_role']._options = None
_EKSCLUSTER.fields_by_name['cluster_autoscaler_role']._options = None
_EKSCLUSTER.fields_by_name['system_node_role']._options = None
_EKSCLUSTER.fields_by_name['subnet_ids']._options = None
_EKSCLUSTER.fields_by_name['cluster_name']._options = None
_EKSCLUSTER.fields_by_name['repository_name']._options = None
_EKSCLUSTER.fields_by_name['storage_bucket_name']._options = None
_EKSCLUSTER.fields_by_name['node_security_group']._options = None
_CREATECLUSTERREQUEST.fields_by_name['parent']._options = None
_CREATECLUSTERREQUEST.fields_by_name['cluster']._options = None
_CREATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_GETCLUSTERREQUEST.fields_by_name['name']._options = None
_RECONCILECLUSTERREQUEST.fields_by_name['name']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['parent']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
_LISTCLUSTERSREQUEST.fields_by_name['order_by']._options = None
_UPDATECLUSTERREQUEST.fields_by_name['cluster']._options = None
_DELETECLUSTERREQUEST.fields_by_name['name']._options = None
_GETCLUSTERCONNECTIONINFOREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



import httpx
from typing import Dict, Optional

from .api_client import FireworksClient as FireworksClientV1
from .chat import Chat
from .completion import CompletionV2
from .embedding import EmbeddingV1
from .rerank import RerankV1
from typing import Union
from .image import ImageInference


class BaseFireworks:
    _organization: str
    _max_retries: int
    _client_v1: FireworksClientV1
    chat: Chat

    def __init__(
        self,
        *,
        api_key: Union[str, None] = None,
        base_url: Union[str, httpx.URL, None] = None,
        timeout: int = 600,
        account: str = "fireworks",
        extra_headers: Optional[Dict[str, str]] = None,
    ):
        self._client_v1 = FireworksClientV1(
            api_key=api_key, base_url=base_url, request_timeout=timeout, extra_headers=extra_headers,
        )
        self._image_client_v1 = ImageInference(
            model=None,
            account=account,
            request_timeout=timeout,
            api_key=api_key,
            base_url=base_url,
        )

        self.completions = CompletionV2(self._client_v1)
        # earlier version had a typo: support both
        self.completion = self.completions
        self.chat = Chat(self._client_v1)
        self.embeddings = EmbeddingV1(self._client_v1)
        self.rerank = RerankV1(self._client_v1)


class Fireworks(BaseFireworks):
    def __enter__(self):
        return self

    def __exit__(self, *exc):
        self.close()

    def close(self):
        return self


class AsyncFireworks(BaseFireworks):
    async def __aenter__(self):
        return self

    async def __aexit__(self, *exc):
        await self.aclose()

    async def aclose(self):
        await self._client_v1.aclose()
        await self._image_client_v1.aclose()



from enum import Enum
from typing import List, Mapping, Optional, Union
from pydantic import BaseModel, Field


class Error(BaseModel, extra="forbid"):
    object: str = "error"
    type: str = "invalid_request_error"
    message: str


class ErrorResponse(BaseModel, extra="forbid"):
    error: Error = Field(default_factory=Error)


class Preprocessing(Enum):
    NONE = "none"

    DYNAMIC = "dynamic"
    """For arbitrary audios with variable loudness and distance from mic"""

    SOFT_DYNAMIC = "soft_dynamic"
    """For podcasts and voice-overs"""

    BASS_DYNAMIC = "bass_dynamic"
    """For audio books, radio, broadcasts and low-frequency speech (e.g. male voices)"""

    def __str__(self):
        return self.value


class TimestampGranularity(Enum):
    WORD = "word"
    SEGMENT = "segment"

    def __str__(self):
        return self.value


class TranscriptionRequest(BaseModel, extra="forbid"):
    model: Optional[str] = None
    vad_model: Optional[str] = None
    alignment_model: Optional[str] = None

    prompt: Optional[str] = None
    response_format: Optional[str] = None
    temperature: Optional[float] = None
    preprocessing: Optional[Preprocessing] = None

    language: Optional[str] = None
    timestamp_granularities: Optional[List[TimestampGranularity]] = None

    def to_multipart(self) -> Mapping[str, Union[str, bytes]]:
        result = {}
        for key, value in self.model_dump(exclude_none=True).items():
            if isinstance(value, (str, bytes)):
                result[key] = value
            elif isinstance(value, list):
                result[key] = ",".join(str(e) for e in value)
            else:
                result[key] = str(value)
        return result


class TranscriptionResponse(BaseModel, extra="forbid"):
    text: str


class TranscriptionWord(BaseModel, extra="forbid"):
    word: str
    start: float
    end: float


class TranscriptionSegment(BaseModel, extra="forbid"):
    id: int
    seek: int
    start: float
    end: float
    text: str
    tokens: List[int]
    temperature: float
    avg_logprob: float
    compression_ratio: float
    no_speech_prob: float


class TranscriptionVerboseResponse(BaseModel, extra="forbid"):
    task: str = "transcribe"  # Not documented by returned by OAI API
    language: str
    duration: float
    text: str
    words: Optional[List[TranscriptionWord]] = None
    segments: Optional[List[TranscriptionSegment]] = None


class TranslationRequest(BaseModel, extra="forbid"):
    model: Optional[str] = None
    vad_model: Optional[str] = None
    alignment_model: Optional[str] = None

    prompt: Optional[str] = None
    response_format: Optional[str] = None
    temperature: Optional[float] = None
    preprocessing: Optional[Preprocessing] = None

    def to_multipart(self) -> Mapping[str, Union[str, bytes]]:
        result = {}
        for key, value in self.model_dump(exclude_none=True).items():
            if isinstance(value, (str, bytes)):
                result[key] = value
            elif isinstance(value, list):
                result[key] = ",".join(str(e) for e in value)
            else:
                result[key] = str(value)
        return result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/sign_in.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/sign_in.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x15gateway/sign_in.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\"\x8f\x01\n\rSignInRequest\x12\x41\n\x0eoauth_provider\x18\x01 \x01(\x0e\x32$.gateway.SignInRequest.OAuthProviderB\x03\xe0\x41\x02\";\n\rOAuthProvider\x12\x1e\n\x1aOAUTH_PROVIDER_UNSPECIFIED\x10\x00\x12\n\n\x06GOOGLE\x10\x01\"3\n\x18GetOAuthArgumentsRequest\x12\x17\n\naccount_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"B\n\x19GetOAuthArgumentsResponse\x12\x12\n\nissuer_url\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\tB\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,])



_SIGNINREQUEST_OAUTHPROVIDER = _descriptor.EnumDescriptor(
  name='OAuthProvider',
  full_name='gateway.SignInRequest.OAuthProvider',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OAUTH_PROVIDER_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOOGLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=152,
  serialized_end=211,
)
_sym_db.RegisterEnumDescriptor(_SIGNINREQUEST_OAUTHPROVIDER)


_SIGNINREQUEST = _descriptor.Descriptor(
  name='SignInRequest',
  full_name='gateway.SignInRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='oauth_provider', full_name='gateway.SignInRequest.oauth_provider', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNINREQUEST_OAUTHPROVIDER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=211,
)


_GETOAUTHARGUMENTSREQUEST = _descriptor.Descriptor(
  name='GetOAuthArgumentsRequest',
  full_name='gateway.GetOAuthArgumentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='gateway.GetOAuthArgumentsRequest.account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=264,
)


_GETOAUTHARGUMENTSRESPONSE = _descriptor.Descriptor(
  name='GetOAuthArgumentsResponse',
  full_name='gateway.GetOAuthArgumentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer_url', full_name='gateway.GetOAuthArgumentsResponse.issuer_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='gateway.GetOAuthArgumentsResponse.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=332,
)

_SIGNINREQUEST.fields_by_name['oauth_provider'].enum_type = _SIGNINREQUEST_OAUTHPROVIDER
_SIGNINREQUEST_OAUTHPROVIDER.containing_type = _SIGNINREQUEST
DESCRIPTOR.message_types_by_name['SignInRequest'] = _SIGNINREQUEST
DESCRIPTOR.message_types_by_name['GetOAuthArgumentsRequest'] = _GETOAUTHARGUMENTSREQUEST
DESCRIPTOR.message_types_by_name['GetOAuthArgumentsResponse'] = _GETOAUTHARGUMENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignInRequest = _reflection.GeneratedProtocolMessageType('SignInRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINREQUEST,
  '__module__' : 'gateway.sign_in_pb2'
  # @@protoc_insertion_point(class_scope:gateway.SignInRequest)
  })
_sym_db.RegisterMessage(SignInRequest)

GetOAuthArgumentsRequest = _reflection.GeneratedProtocolMessageType('GetOAuthArgumentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOAUTHARGUMENTSREQUEST,
  '__module__' : 'gateway.sign_in_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetOAuthArgumentsRequest)
  })
_sym_db.RegisterMessage(GetOAuthArgumentsRequest)

GetOAuthArgumentsResponse = _reflection.GeneratedProtocolMessageType('GetOAuthArgumentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOAUTHARGUMENTSRESPONSE,
  '__module__' : 'gateway.sign_in_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetOAuthArgumentsResponse)
  })
_sym_db.RegisterMessage(GetOAuthArgumentsResponse)


DESCRIPTOR._options = None
_SIGNINREQUEST.fields_by_name['oauth_provider']._options = None
_GETOAUTHARGUMENTSREQUEST.fields_by_name['account_id']._options = None
# @@protoc_insertion_point(module_scope)
